## dbt-bigquery 1.11.0-rc3 - December 17, 2025

### Features

- Support BigQuery STRUCT schema change ([#599](https://github.com/dbt-labs/dbt-adapters/issues/599))

### Contributors
- [@Kayrnt](https://github.com/Kayrnt) ([#599](https://github.com/dbt-labs/dbt-adapters/issues/599))
